==> haskell-integer-logarithms-1.0.1-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-integer-logarithms.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: integer-logarithms
version: 1.0.1
id: integer-logarithms-1.0.1-BMmDc9fXSmWBX4AQeoakwE
key: integer-logarithms-1.0.1-BMmDc9fXSmWBX4AQeoakwE
license: MIT
copyright: (c) 2011 Daniel Fischer
maintainer: Oleg Grenrus <oleg.grenrus@iki.fi>
stability: Provisional
homepage: https://github.com/phadej/integer-logarithms
synopsis: Integer logarithms.
description:
    "Math.NumberTheory.Logarithms" and "Math.NumberTheory.Powers.Integer"
    from the arithmoi package.
    .
    Also provides "GHC.Integer.Logarithms.Compat" and
    "Math.NumberTheory.Power.Natural" modules, as well as some
    additional functions in migrated modules.
category: Math, Algorithms, Number Theory
author: Daniel Fischer
exposed: True
exposed-modules:
    Math.NumberTheory.Logarithms Math.NumberTheory.Powers.Integer
    Math.NumberTheory.Powers.Natural GHC.Integer.Logarithms.Compat
abi: 6d937c35bb60cffbb0724540fe7b0bc5
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/integer-logarithms-1.0.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/integer-logarithms-1.0.1
data-dir: /usr/share/arm-linux-ghc-8.0.1/integer-logarithms-1.0.1
hs-libraries: HSinteger-logarithms-1.0.1-BMmDc9fXSmWBX4AQeoakwE
depends:
    array-0.5.1.1 base-4.9.0.0 ghc-prim-0.5.0.0 integer-gmp-1.0.0.1
haddock-interfaces: /usr/share/doc/haskell-integer-logarithms/html/integer-logarithms.haddock
haddock-html: /usr/share/doc/haskell-integer-logarithms/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-integer-logarithms-1.0.1-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-integer-logarithms.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: integer-logarithms
version: 1.0.1
id: integer-logarithms-1.0.1-41Vx8Gc1I6fAYpZXPW8o2w
key: integer-logarithms-1.0.1-41Vx8Gc1I6fAYpZXPW8o2w
license: MIT
copyright: (c) 2011 Daniel Fischer
maintainer: Oleg Grenrus <oleg.grenrus@iki.fi>
stability: Provisional
homepage: https://github.com/phadej/integer-logarithms
synopsis: Integer logarithms.
description:
    "Math.NumberTheory.Logarithms" and "Math.NumberTheory.Powers.Integer"
    from the arithmoi package.
    .
    Also provides "GHC.Integer.Logarithms.Compat" and
    "Math.NumberTheory.Power.Natural" modules, as well as some
    additional functions in migrated modules.
category: Math, Algorithms, Number Theory
author: Daniel Fischer
exposed: True
exposed-modules:
    Math.NumberTheory.Logarithms Math.NumberTheory.Powers.Integer
    Math.NumberTheory.Powers.Natural GHC.Integer.Logarithms.Compat
abi: 58beec7c0a8f435a390f8699e6efd37e
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/integer-logarithms-1.0.1
library-dirs: /usr/lib/ghc-8.0.2/site-local/integer-logarithms-1.0.1
dynamic-library-dirs: /usr/lib/arm-linux-ghc-8.0.2
data-dir: /usr/share/arm-linux-ghc-8.0.2/integer-logarithms-1.0.1
hs-libraries: HSinteger-logarithms-1.0.1-41Vx8Gc1I6fAYpZXPW8o2w
depends:
    array-0.5.1.1 base-4.9.1.0 ghc-prim-0.5.0.0 integer-gmp-1.0.0.1
haddock-interfaces: /usr/share/doc/haskell-integer-logarithms/html/integer-logarithms.haddock
haddock-html: /usr/share/doc/haskell-integer-logarithms/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
